<?php

class Csomagpont_Filter
{

    public function __construct()
    {
        // $this->csomagpont_settings_obj = new Csomagpont_Settings();
        add_action('restrict_manage_posts', array($this, 'not_exported_products_filter'));
        add_action('pre_get_posts', array($this, 'apply_not_exported_products_filter'));
        add_filter('manage_edit-shop_order_columns', array($this, 'add_order_group_code_column_header'), 20);
        add_action('manage_shop_order_posts_custom_column', array($this, 'add_order_group_code_column_content'));
        add_filter('post_class', function ($classes) {
            $classes[] = 'no-link';
            return $classes;

        });
    }

    public function add_order_group_code_column_header($columns)
    {

        $new_columns = array();
        $index = 0;

        foreach ($columns as $column_name => $column_info) {
            $new_columns[$column_name] = $column_info;

            if ($index == 1) {
                $new_columns['group_code'] = 'Csomag azonosító';
            }

            $index += 1;
        }

        return $new_columns;
    }

    public function add_order_group_code_column_content($column)
    {
        global $post;

        if ($column == 'group_code') {
            $exported = get_metadata('post', $post->ID, '_csomagpont_exported', true);
            $group_code = get_metadata('post', $post->ID, '_group_code', true);
            $delivery = get_metadata('post', $post->ID, '_delivery', true);

            // Csomagpont szűrés Szathmári pluginnal
            $pont_metadata = get_metadata('post', $post->ID, 'wc_selected_pont', true);
            

            if ($exported == 'true') {
                echo '<span class="csomagpont-cell" style="cursor:pointer;font-weight:600;color:#0073aa;" data-groupid="' . $group_code . '" data-dsmid="' . $delivery . '"> '.$group_code .'</span>';
                if ($delivery == CSP_SZALLMOD_MPL_PONT || $delivery == CSP_SZALLMOD_MPL_ALTER) {
                    echo '<img class="csp-mpl-sent" title="MPL feladójegyzék tartozhat ehhez a csomaghoz" src="' . CSOMAGPONT_DIR_URL . 'images/csomagpont-signature.png">';
                }
            } else if ($pont_metadata) {
                // Csomagpont beállítás Szathmári pluginnal
                $pont_type = explode('|', get_metadata('post', $post->ID, 'wc_selected_pont', true))[1];
                if ($pont_type === 'GLS CsomagPont') {
                    echo '<select name="csomagpont-'.$post->ID.'" disabled>';
                    echo '<option value="' . $post->ID . "-". CSP_SZALLMOD_GLS_PONT . '" selected>' . 'GLS csomagpont' . '</option>';
                    echo '</select>';
                } else if ($pont_type === 'PostaPont Csomagautomata' || $pont_type === 'Posta Pont') {
                    echo '<select name="csomagpont-'.$post->ID.'" disabled>';
                    echo '<option value="' . $post->ID . "-". CSP_SZALLMOD_MPL_PONT . '" selected>' . 'MPL csomagpont' . '</option>';
                    echo '</select>';
                } else {
                    echo 'Nem támogatott csomagátvételi pont';
                }
            } else {
							$csomagpont_api = new Csomagpont_API(new Csomagpont_Settings());
							$shipping_options = $csomagpont_api->get_shipping_options();
                $selected = '';
                echo '<select name="csomagpont-'.$post->ID.'" title="Válasszon szállítási módot">';
                foreach ($shipping_options as $option) {
                    if ($csomagpont_api->api_settings_obj->csomagpont_settings["delivery"] == $option->value) {
                        $selected = 'selected';
                    } else {
											$selected = '';
										}
                    echo '<option value="' . $post->ID . "-". $option->value . '" ' . $selected . '>' . $option->description . '</option>';
                }
                echo '</select>';
            }
        }
    }

    /* Order filter functions */
    public function not_exported_products_filter($post_type)
    {
        if (isset($_GET['post_type'])) {
            $post_type = sanitize_text_field($_GET['post_type']);
        }

        $selected_1 = '';
        $selected_2 = '';

        if (isset($_GET['deliveo_exported'])) {
            switch (sanitize_text_field($_GET['deliveo_exported'])) {
                case 'not_exported':$selected_1 = 'selected';
                    break;
                case 'exported':$selected_2 = 'selected';
                    break;
            }
        }

        if ($post_type == 'shop_order') {
            echo '
			<select name="deliveo_exported">
				<option value="">' . __('Csomagpont szűrés: mind', 'csomagpont') . '</option>
				<option value="not_exported" ' . $selected_1 . '>' . __('Feladatlan', 'csomagpont') . '</option>
				<option value="exported" ' . $selected_2 . '>' . __('Feladott', 'csomagpont') . '</option>
			</select>';
        }

        // Plusz funkció: Töltőképernyő
        echo '<div class="csp-loader"><img src="' . plugin_dir_url(__DIR__) . 'images/loader.gif"></div>';

    }

    /* In the Orders admin page when the csomagpont filter was applied, this query filter will working  */
    public function apply_not_exported_products_filter($query)
    {
        global $pagenow;

        $meta_key_query = array();

        if ($query->is_admin && $pagenow == 'edit.php' && isset($_GET['deliveo_exported']) && sanitize_text_field($_GET['deliveo_exported']) != '' && sanitize_text_field($_GET['post_type']) == 'shop_order') {
            switch (sanitize_text_field($_GET['deliveo_exported'])) {
                case 'not_exported':
                    $query_filters = array(
                        'key' => '_csomagpont_exported',
                        'compare' => 'NOT EXISTS',
                    );
                    break;

                case 'exported':
                    $query_filters = array(
                        'key' => '_csomagpont_exported',
                        'value' => 'true',
                    );
                    break;
            }

            $meta_key_query = array($query_filters);

            if (count($meta_key_query > 0)) {
                $query->set('meta_query', $meta_key_query);
            }
        }
    }

}
